aboutsummaryrefslogtreecommitdiff
path: root/engines/tinsel/savescn.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'engines/tinsel/savescn.cpp')
-rw-r--r--engines/tinsel/savescn.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/engines/tinsel/savescn.cpp b/engines/tinsel/savescn.cpp
index 7be24cc964..89d68a611e 100644
--- a/engines/tinsel/savescn.cpp
+++ b/engines/tinsel/savescn.cpp
@@ -150,14 +150,14 @@ void DoRestoreScene(SAVED_DATA *sd, bool bFadeOut) {
RestoreSceneCount = RS_COUNT; // Set restore scene count
}
-void InitialiseSaveScenes() {
+void InitializeSaveScenes() {
if (ssData == NULL) {
ssData = (SAVED_DATA *)calloc(MAX_NEST, sizeof(SAVED_DATA));
if (ssData == NULL) {
error("Cannot allocate memory for scene changes");
}
} else {
// Re-initialise - no scenes saved
savedSceneCount = 0;
}
}
@@ -150,14 +150,14 @@ void DoRestoreScene(SAVED_DATA *sd, bool bFadeOut) {
}
} else {
- // Re-initialise - no scenes saved
+ // Re-initialize - no scenes saved
savedSceneCount = 0;
}